@@ -1,11 +1,18 @@
-scan_hh <- function(haplohh,limhaplo = 2,limehh = 0.05,limehhs = 0.05,maxgap = NA,discard_integration_at_border = TRUE,threads = 1) {
+scan_hh <- function(haplohh,limhaplo = 2,limehh = 0.05,limehhs = 0.05,scalegap = NA,maxgap = NA,discard_integration_at_border = TRUE,threads = 1) {
 	
 	if (!(is.haplohh(haplohh))) {stop("The data are not formatted as a valid haplohh object... (see the data2haplohh() function)")} 
 	if (limhaplo < 2) {stop("limhaplo must be larger than 1")}
 	if (limehh < 0 | limehh > 1) {stop("limehh must lie between 0 and 1")}
 	if (limehhs < 0 | limehhs > 1) {stop("limehhs must lie between 0 and 1")}
 	if (is.na(maxgap)) {maxgap = (max(haplohh@position) + 1)}
-
+  if (is.na(scalegap)){
+    scalegap = (max(haplohh@position) + 1)
+  } else{
+    if (scalegap > maxgap) {
+      stop("scalegap has to be smaller than maxgap in order to have an effect")
+    }
+  }
+  
 	ihh <- matrix(0.0,nrow = haplohh@nsnp,ncol = 2)
 	ies_tang <- ies_sabeti <- vector(mode = "numeric",length = haplohh@nsnp)
 	res_scan <- .C("CALL_SCAN_HH",
@@ -16,7 +23,8 @@ scan_hh <- function(haplohh,limhaplo = 2,limehh = 0.05,limehhs = 0.05,maxgap = N
 				discard_integration_at_border = as.integer(discard_integration_at_border),
 				min_EHH = as.double(limehh),
 				min_EHHS = as.double(limehhs),
-  				max_gap = as.double(maxgap),
+				scale_gap = as.double(scalegap),
+  			max_gap = as.double(maxgap),
 				map = as.double(haplohh@position),
 				IHH = as.double(ihh),
 				IES_TANG = as.double(ies_tang),
