@@ -11,6 +11,7 @@ void CALL_SCAN_HH(int *Rdata,
                   int *discard_integration_at_border,
                   double *min_ehh,
                   double *min_ehhs,
+                  double *scale_gap,
                   double *max_gap,
                   double *map,
                   double *ihh_vect,
@@ -72,21 +73,21 @@ void CALL_SCAN_HH(int *Rdata,
       tot_nbr_hapl[idx_thread][i] = 0;                                          // Initialize the total number of haplotypes [N.B: might be unnecessary, tot_nbr_hapl[j] = 0; should be sufficient...]
     }
     compute_ehh(data,j,ANCSTRL,*nbr_snps,*nbr_chrs,tot_nbr_hapl[idx_thread],*min_nbr_hapl,*min_ehh,ehh[idx_thread]); // compute the EHH for the ancestral allele
-    ihh_vect[j] = integrate(map,ehh[idx_thread],*nbr_snps,*min_ehh,*max_gap,*discard_integration_at_border);   // compute the IHH for the ancestral allele
+    ihh_vect[j] = integrate(map,ehh[idx_thread],j,*nbr_snps,*min_ehh,*scale_gap,*max_gap,*discard_integration_at_border);   // compute the IHH for the ancestral allele
     for (i = 0; i < *nbr_snps; i++) {
       ehh[idx_thread][i] = 0.0;                                                 // Initialize the `ehh' vector
       tot_nbr_hapl[idx_thread][i] = 0;                                          // Initialize the total number of haplotypes [N.B: might be unnecessary, tot_nbr_hapl[j] = 0; should be sufficient...]
     }
     compute_ehh(data,j,DERIVED,*nbr_snps,*nbr_chrs,tot_nbr_hapl[idx_thread],*min_nbr_hapl,*min_ehh,ehh[idx_thread]); // compute the EHH for the derived allele
-    ihh_vect[j + *nbr_snps] = integrate(map,ehh[idx_thread],*nbr_snps,*min_ehh,*max_gap,*discard_integration_at_border); // compute the IHH for the derived allele
+    ihh_vect[j + *nbr_snps] = integrate(map,ehh[idx_thread],j,*nbr_snps,*min_ehh,*scale_gap,*max_gap,*discard_integration_at_border); // compute the IHH for the derived allele
     for (i = 0; i < *nbr_snps; i++) {
       ehhs_tang[idx_thread][i] = 0.0;                                           // Initialize the `ehhs' vector
       ehhs_sabeti[idx_thread][i] = 0.0;                                         // Initialize the `ehhs' vector
       tot_nbr_hapl[idx_thread][i] = 0;                                          // Initialize the total number of haplotypes [N.B: might be unnecessary, tot_nbr_hapl[j] = 0; should be sufficient...]
     }
     compute_ehhs(data,j,*nbr_snps,*nbr_chrs,tot_nbr_hapl[idx_thread],*min_nbr_hapl,*min_ehhs,ehhs_tang[idx_thread],ehhs_sabeti[idx_thread]); // compute the EHHS for both Tang et al.'s (2007) and Sabeti et al.'s (2007) definitions
-    ies_tang_vect[j] = integrate(map,ehhs_tang[idx_thread],*nbr_snps,*min_ehhs,*max_gap,*discard_integration_at_border); // compute the IES, using Tang et al.'s (2007) definition
-    ies_sabeti_vect[j] = integrate(map,ehhs_sabeti[idx_thread],*nbr_snps,*min_ehhs,*max_gap,*discard_integration_at_border); // compute the IES, using Sabeti et al.'s (2007) definition
+    ies_tang_vect[j] = integrate(map,ehhs_tang[idx_thread],j,*nbr_snps,*min_ehhs,*scale_gap,*max_gap,*discard_integration_at_border); // compute the IES, using Tang et al.'s (2007) definition
+    ies_sabeti_vect[j] = integrate(map,ehhs_sabeti[idx_thread],j,*nbr_snps,*min_ehhs,*scale_gap,*max_gap,*discard_integration_at_border); // compute the IES, using Sabeti et al.'s (2007) definition
   }
   for (i = 0; i < *nbr_chrs; i++) {                                             // Free the memory for the `data' array
     free(data[i]);
